@@ -10,9 +10,15 @@ class TestForceTextToStrCommand(CodemodTest):
     def test_noop(self) -> None:
         """Test when nothing should change."""
         before = """
+            from django import conf
+            from django.utils import encoding
+
             foo = force_str("bar")
         """
         after = """
+            from django import conf
+            from django.utils import encoding
+
             foo = force_str("bar")
         """
 
@@ -45,3 +51,23 @@ class TestForceTextToStrCommand(CodemodTest):
             result = force_str(content)
         """
         self.assertCodemod(before, after)
+
+    def test_call_no_value(self) -> None:
+        """Regression test for function call without name."""
+        before = """
+            factory()()
+        """
+        after = """
+            factory()()
+        """
+        self.assertCodemod(before, after)
+
+    def test_lambda_no_value(self) -> None:
+        """Regression test for lambda call without name."""
+        before = """
+            (lambda x: x)(something)
+        """
+        after = """
+            (lambda x: x)(something)
+        """
+        self.assertCodemod(before, after)
